@@ -25,38 +25,34 @@ class AddContainerAppRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'EHPC', '2018-04-12', 'AddContainerApp')
 		self.set_method('GET')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_Description(self):
+	def get_Description(self): # String
 		return self.get_query_params().get('Description')
 
-	def set_Description(self,Description):
-		self.add_query_param('Description',Description)
-
-	def get_Repository(self):
+	def set_Description(self, Description):  # String
+		self.add_query_param('Description', Description)
+	def get_Repository(self): # String
 		return self.get_query_params().get('Repository')
 
-	def set_Repository(self,Repository):
-		self.add_query_param('Repository',Repository)
-
-	def get_ContainerType(self):
+	def set_Repository(self, Repository):  # String
+		self.add_query_param('Repository', Repository)
+	def get_ContainerType(self): # String
 		return self.get_query_params().get('ContainerType')
 
-	def set_ContainerType(self,ContainerType):
-		self.add_query_param('ContainerType',ContainerType)
-
-	def get_Name(self):
+	def set_ContainerType(self, ContainerType):  # String
+		self.add_query_param('ContainerType', ContainerType)
+	def get_Name(self): # String
 		return self.get_query_params().get('Name')
 
-	def set_Name(self,Name):
-		self.add_query_param('Name',Name)
-
-	def get_ImageTag(self):
+	def set_Name(self, Name):  # String
+		self.add_query_param('Name', Name)
+	def get_ImageTag(self): # String
 		return self.get_query_params().get('ImageTag')
 
-	def set_ImageTag(self,ImageTag):
-		self.add_query_param('ImageTag',ImageTag)
\ No newline at end of file
+	def set_ImageTag(self, ImageTag):  # String
+		self.add_query_param('ImageTag', ImageTag)
