@@ -25,20 +25,24 @@ class AddLocalNodesRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'EHPC', '2018-04-12', 'AddLocalNodes')
 		self.set_method('GET')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_ClusterId(self):
+	def get_ClusterId(self): # String
 		return self.get_query_params().get('ClusterId')
 
-	def set_ClusterId(self,ClusterId):
-		self.add_query_param('ClusterId',ClusterId)
-
-	def get_Nodes(self):
+	def set_ClusterId(self, ClusterId):  # String
+		self.add_query_param('ClusterId', ClusterId)
+	def get_Nodes(self): # String
 		return self.get_query_params().get('Nodes')
 
-	def set_Nodes(self,Nodes):
-		self.add_query_param('Nodes',Nodes)
\ No newline at end of file
+	def set_Nodes(self, Nodes):  # String
+		self.add_query_param('Nodes', Nodes)
+	def get_Queue(self): # String
+		return self.get_query_params().get('Queue')
+
+	def set_Queue(self, Queue):  # String
+		self.add_query_param('Queue', Queue)
