@@ -25,14 +25,14 @@ class DescribeContainerAppRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'EHPC', '2018-04-12', 'DescribeContainerApp')
 		self.set_method('GET')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_ContainerId(self):
+	def get_ContainerId(self): # String
 		return self.get_query_params().get('ContainerId')
 
-	def set_ContainerId(self,ContainerId):
-		self.add_query_param('ContainerId',ContainerId)
\ No newline at end of file
+	def set_ContainerId(self, ContainerId):  # String
+		self.add_query_param('ContainerId', ContainerId)
