@@ -25,32 +25,29 @@ class DescribeImageRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'EHPC', '2018-04-12', 'DescribeImage')
 		self.set_method('GET')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_ClusterId(self):
+	def get_ClusterId(self): # String
 		return self.get_query_params().get('ClusterId')
 
-	def set_ClusterId(self,ClusterId):
-		self.add_query_param('ClusterId',ClusterId)
-
-	def get_Repository(self):
+	def set_ClusterId(self, ClusterId):  # String
+		self.add_query_param('ClusterId', ClusterId)
+	def get_Repository(self): # String
 		return self.get_query_params().get('Repository')
 
-	def set_Repository(self,Repository):
-		self.add_query_param('Repository',Repository)
-
-	def get_ContainerType(self):
+	def set_Repository(self, Repository):  # String
+		self.add_query_param('Repository', Repository)
+	def get_ContainerType(self): # String
 		return self.get_query_params().get('ContainerType')
 
-	def set_ContainerType(self,ContainerType):
-		self.add_query_param('ContainerType',ContainerType)
-
-	def get_ImageTag(self):
+	def set_ContainerType(self, ContainerType):  # String
+		self.add_query_param('ContainerType', ContainerType)
+	def get_ImageTag(self): # String
 		return self.get_query_params().get('ImageTag')
 
-	def set_ImageTag(self,ImageTag):
-		self.add_query_param('ImageTag',ImageTag)
\ No newline at end of file
+	def set_ImageTag(self, ImageTag):  # String
+		self.add_query_param('ImageTag', ImageTag)
