@@ -25,44 +25,39 @@ class ListJobsRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'EHPC', '2018-04-12', 'ListJobs')
 		self.set_method('GET')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_Owner(self):
+	def get_Owner(self): # String
 		return self.get_query_params().get('Owner')
 
-	def set_Owner(self,Owner):
-		self.add_query_param('Owner',Owner)
-
-	def get_ClusterId(self):
+	def set_Owner(self, Owner):  # String
+		self.add_query_param('Owner', Owner)
+	def get_ClusterId(self): # String
 		return self.get_query_params().get('ClusterId')
 
-	def set_ClusterId(self,ClusterId):
-		self.add_query_param('ClusterId',ClusterId)
-
-	def get_Rerunable(self):
+	def set_ClusterId(self, ClusterId):  # String
+		self.add_query_param('ClusterId', ClusterId)
+	def get_Rerunable(self): # String
 		return self.get_query_params().get('Rerunable')
 
-	def set_Rerunable(self,Rerunable):
-		self.add_query_param('Rerunable',Rerunable)
-
-	def get_PageNumber(self):
+	def set_Rerunable(self, Rerunable):  # String
+		self.add_query_param('Rerunable', Rerunable)
+	def get_PageNumber(self): # Integer
 		return self.get_query_params().get('PageNumber')
 
-	def set_PageNumber(self,PageNumber):
-		self.add_query_param('PageNumber',PageNumber)
-
-	def get_PageSize(self):
+	def set_PageNumber(self, PageNumber):  # Integer
+		self.add_query_param('PageNumber', PageNumber)
+	def get_PageSize(self): # Integer
 		return self.get_query_params().get('PageSize')
 
-	def set_PageSize(self,PageSize):
-		self.add_query_param('PageSize',PageSize)
-
-	def get_State(self):
+	def set_PageSize(self, PageSize):  # Integer
+		self.add_query_param('PageSize', PageSize)
+	def get_State(self): # String
 		return self.get_query_params().get('State')
 
-	def set_State(self,State):
-		self.add_query_param('State',State)
\ No newline at end of file
+	def set_State(self, State):  # String
+		self.add_query_param('State', State)
