@@ -25,74 +25,64 @@ class ListNodesRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'EHPC', '2018-04-12', 'ListNodes')
 		self.set_method('GET')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_Role(self):
+	def get_Role(self): # String
 		return self.get_query_params().get('Role')
 
-	def set_Role(self,Role):
-		self.add_query_param('Role',Role)
-
-	def get_PageNumber(self):
+	def set_Role(self, Role):  # String
+		self.add_query_param('Role', Role)
+	def get_PageNumber(self): # Integer
 		return self.get_query_params().get('PageNumber')
 
-	def set_PageNumber(self,PageNumber):
-		self.add_query_param('PageNumber',PageNumber)
-
-	def get_HostName(self):
+	def set_PageNumber(self, PageNumber):  # Integer
+		self.add_query_param('PageNumber', PageNumber)
+	def get_HostName(self): # String
 		return self.get_query_params().get('HostName')
 
-	def set_HostName(self,HostName):
-		self.add_query_param('HostName',HostName)
-
-	def get_PageSize(self):
+	def set_HostName(self, HostName):  # String
+		self.add_query_param('HostName', HostName)
+	def get_PageSize(self): # Integer
 		return self.get_query_params().get('PageSize')
 
-	def set_PageSize(self,PageSize):
-		self.add_query_param('PageSize',PageSize)
-
-	def get_HostNamePrefix(self):
+	def set_PageSize(self, PageSize):  # Integer
+		self.add_query_param('PageSize', PageSize)
+	def get_HostNamePrefix(self): # String
 		return self.get_query_params().get('HostNamePrefix')
 
-	def set_HostNamePrefix(self,HostNamePrefix):
-		self.add_query_param('HostNamePrefix',HostNamePrefix)
-
-	def get_ClusterId(self):
+	def set_HostNamePrefix(self, HostNamePrefix):  # String
+		self.add_query_param('HostNamePrefix', HostNamePrefix)
+	def get_ClusterId(self): # String
 		return self.get_query_params().get('ClusterId')
 
-	def set_ClusterId(self,ClusterId):
-		self.add_query_param('ClusterId',ClusterId)
-
-	def get_HostNameSuffix(self):
+	def set_ClusterId(self, ClusterId):  # String
+		self.add_query_param('ClusterId', ClusterId)
+	def get_HostNameSuffix(self): # String
 		return self.get_query_params().get('HostNameSuffix')
 
-	def set_HostNameSuffix(self,HostNameSuffix):
-		self.add_query_param('HostNameSuffix',HostNameSuffix)
-
-	def get_Filter(self):
+	def set_HostNameSuffix(self, HostNameSuffix):  # String
+		self.add_query_param('HostNameSuffix', HostNameSuffix)
+	def get_Filter(self): # String
 		return self.get_query_params().get('Filter')
 
-	def set_Filter(self,Filter):
-		self.add_query_param('Filter',Filter)
-
-	def get_PrivateIpAddress(self):
+	def set_Filter(self, Filter):  # String
+		self.add_query_param('Filter', Filter)
+	def get_PrivateIpAddress(self): # String
 		return self.get_query_params().get('PrivateIpAddress')
 
-	def set_PrivateIpAddress(self,PrivateIpAddress):
-		self.add_query_param('PrivateIpAddress',PrivateIpAddress)
-
-	def get_Sequence(self):
+	def set_PrivateIpAddress(self, PrivateIpAddress):  # String
+		self.add_query_param('PrivateIpAddress', PrivateIpAddress)
+	def get_Sequence(self): # String
 		return self.get_query_params().get('Sequence')
 
-	def set_Sequence(self,Sequence):
-		self.add_query_param('Sequence',Sequence)
-
-	def get_SortBy(self):
+	def set_Sequence(self, Sequence):  # String
+		self.add_query_param('Sequence', Sequence)
+	def get_SortBy(self): # String
 		return self.get_query_params().get('SortBy')
 
-	def set_SortBy(self,SortBy):
-		self.add_query_param('SortBy',SortBy)
\ No newline at end of file
+	def set_SortBy(self, SortBy):  # String
+		self.add_query_param('SortBy', SortBy)
