@@ -25,68 +25,60 @@ class ModifyImageGatewayConfigRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'EHPC', '2018-04-12', 'ModifyImageGatewayConfig')
 		self.set_method('GET')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_Repos(self):
+	def get_Repos(self): # RepeatList
 		return self.get_query_params().get('Repo')
 
-	def set_Repos(self, Repos):
-		for depth1 in range(len(Repos)):
-			if Repos[depth1].get('Auth') is not None:
-				self.add_query_param('Repo.' + str(depth1 + 1) + '.Auth', Repos[depth1].get('Auth'))
-			if Repos[depth1].get('Location') is not None:
-				self.add_query_param('Repo.' + str(depth1 + 1) + '.Location', Repos[depth1].get('Location'))
-			if Repos[depth1].get('URL') is not None:
-				self.add_query_param('Repo.' + str(depth1 + 1) + '.URL', Repos[depth1].get('URL'))
-
-	def get_DBServerInfo(self):
+	def set_Repos(self, Repo):  # RepeatList
+		for depth1 in range(len(Repo)):
+			if Repo[depth1].get('Auth') is not None:
+				self.add_query_param('Repo.' + str(depth1 + 1) + '.Auth', Repo[depth1].get('Auth'))
+			if Repo[depth1].get('Location') is not None:
+				self.add_query_param('Repo.' + str(depth1 + 1) + '.Location', Repo[depth1].get('Location'))
+			if Repo[depth1].get('URL') is not None:
+				self.add_query_param('Repo.' + str(depth1 + 1) + '.URL', Repo[depth1].get('URL'))
+	def get_DBServerInfo(self): # String
 		return self.get_query_params().get('DBServerInfo')
 
-	def set_DBServerInfo(self,DBServerInfo):
-		self.add_query_param('DBServerInfo',DBServerInfo)
-
-	def get_ClusterId(self):
+	def set_DBServerInfo(self, DBServerInfo):  # String
+		self.add_query_param('DBServerInfo', DBServerInfo)
+	def get_ClusterId(self): # String
 		return self.get_query_params().get('ClusterId')
 
-	def set_ClusterId(self,ClusterId):
-		self.add_query_param('ClusterId',ClusterId)
-
-	def get_DefaultRepoLocation(self):
+	def set_ClusterId(self, ClusterId):  # String
+		self.add_query_param('ClusterId', ClusterId)
+	def get_DefaultRepoLocation(self): # String
 		return self.get_query_params().get('DefaultRepoLocation')
 
-	def set_DefaultRepoLocation(self,DefaultRepoLocation):
-		self.add_query_param('DefaultRepoLocation',DefaultRepoLocation)
-
-	def get_DBPassword(self):
+	def set_DefaultRepoLocation(self, DefaultRepoLocation):  # String
+		self.add_query_param('DefaultRepoLocation', DefaultRepoLocation)
+	def get_DBPassword(self): # String
 		return self.get_query_params().get('DBPassword')
 
-	def set_DBPassword(self,DBPassword):
-		self.add_query_param('DBPassword',DBPassword)
-
-	def get_DBType(self):
+	def set_DBPassword(self, DBPassword):  # String
+		self.add_query_param('DBPassword', DBPassword)
+	def get_DBType(self): # String
 		return self.get_query_params().get('DBType')
 
-	def set_DBType(self,DBType):
-		self.add_query_param('DBType',DBType)
-
-	def get_DBUsername(self):
+	def set_DBType(self, DBType):  # String
+		self.add_query_param('DBType', DBType)
+	def get_DBUsername(self): # String
 		return self.get_query_params().get('DBUsername')
 
-	def set_DBUsername(self,DBUsername):
-		self.add_query_param('DBUsername',DBUsername)
-
-	def get_PullUpdateTimeout(self):
+	def set_DBUsername(self, DBUsername):  # String
+		self.add_query_param('DBUsername', DBUsername)
+	def get_PullUpdateTimeout(self): # Integer
 		return self.get_query_params().get('PullUpdateTimeout')
 
-	def set_PullUpdateTimeout(self,PullUpdateTimeout):
-		self.add_query_param('PullUpdateTimeout',PullUpdateTimeout)
-
-	def get_ImageExpirationTimeout(self):
+	def set_PullUpdateTimeout(self, PullUpdateTimeout):  # Integer
+		self.add_query_param('PullUpdateTimeout', PullUpdateTimeout)
+	def get_ImageExpirationTimeout(self): # String
 		return self.get_query_params().get('ImageExpirationTimeout')
 
-	def set_ImageExpirationTimeout(self,ImageExpirationTimeout):
-		self.add_query_param('ImageExpirationTimeout',ImageExpirationTimeout)
\ No newline at end of file
+	def set_ImageExpirationTimeout(self, ImageExpirationTimeout):  # String
+		self.add_query_param('ImageExpirationTimeout', ImageExpirationTimeout)
