@@ -25,38 +25,34 @@ class MountNFSRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'EHPC', '2018-04-12', 'MountNFS')
 		self.set_method('GET')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_MountDir(self):
+	def get_MountDir(self): # String
 		return self.get_query_params().get('MountDir')
 
-	def set_MountDir(self,MountDir):
-		self.add_query_param('MountDir',MountDir)
-
-	def get_InstanceId(self):
+	def set_MountDir(self, MountDir):  # String
+		self.add_query_param('MountDir', MountDir)
+	def get_InstanceId(self): # String
 		return self.get_query_params().get('InstanceId')
 
-	def set_InstanceId(self,InstanceId):
-		self.add_query_param('InstanceId',InstanceId)
-
-	def get_RemoteDir(self):
+	def set_InstanceId(self, InstanceId):  # String
+		self.add_query_param('InstanceId', InstanceId)
+	def get_RemoteDir(self): # String
 		return self.get_query_params().get('RemoteDir')
 
-	def set_RemoteDir(self,RemoteDir):
-		self.add_query_param('RemoteDir',RemoteDir)
-
-	def get_NfsDir(self):
+	def set_RemoteDir(self, RemoteDir):  # String
+		self.add_query_param('RemoteDir', RemoteDir)
+	def get_NfsDir(self): # String
 		return self.get_query_params().get('NfsDir')
 
-	def set_NfsDir(self,NfsDir):
-		self.add_query_param('NfsDir',NfsDir)
-
-	def get_ProtocolType(self):
+	def set_NfsDir(self, NfsDir):  # String
+		self.add_query_param('NfsDir', NfsDir)
+	def get_ProtocolType(self): # String
 		return self.get_query_params().get('ProtocolType')
 
-	def set_ProtocolType(self,ProtocolType):
-		self.add_query_param('ProtocolType',ProtocolType)
\ No newline at end of file
+	def set_ProtocolType(self, ProtocolType):  # String
+		self.add_query_param('ProtocolType', ProtocolType)
