@@ -25,50 +25,44 @@ class RecoverClusterRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'EHPC', '2018-04-12', 'RecoverCluster')
 		self.set_method('GET')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_ImageId(self):
+	def get_ImageId(self): # String
 		return self.get_query_params().get('ImageId')
 
-	def set_ImageId(self,ImageId):
-		self.add_query_param('ImageId',ImageId)
-
-	def get_OsTag(self):
+	def set_ImageId(self, ImageId):  # String
+		self.add_query_param('ImageId', ImageId)
+	def get_OsTag(self): # String
 		return self.get_query_params().get('OsTag')
 
-	def set_OsTag(self,OsTag):
-		self.add_query_param('OsTag',OsTag)
-
-	def get_ClientVersion(self):
+	def set_OsTag(self, OsTag):  # String
+		self.add_query_param('OsTag', OsTag)
+	def get_ClientVersion(self): # String
 		return self.get_query_params().get('ClientVersion')
 
-	def set_ClientVersion(self,ClientVersion):
-		self.add_query_param('ClientVersion',ClientVersion)
-
-	def get_AccountType(self):
+	def set_ClientVersion(self, ClientVersion):  # String
+		self.add_query_param('ClientVersion', ClientVersion)
+	def get_AccountType(self): # String
 		return self.get_query_params().get('AccountType')
 
-	def set_AccountType(self,AccountType):
-		self.add_query_param('AccountType',AccountType)
-
-	def get_ClusterId(self):
+	def set_AccountType(self, AccountType):  # String
+		self.add_query_param('AccountType', AccountType)
+	def get_ClusterId(self): # String
 		return self.get_query_params().get('ClusterId')
 
-	def set_ClusterId(self,ClusterId):
-		self.add_query_param('ClusterId',ClusterId)
-
-	def get_ImageOwnerAlias(self):
+	def set_ClusterId(self, ClusterId):  # String
+		self.add_query_param('ClusterId', ClusterId)
+	def get_ImageOwnerAlias(self): # String
 		return self.get_query_params().get('ImageOwnerAlias')
 
-	def set_ImageOwnerAlias(self,ImageOwnerAlias):
-		self.add_query_param('ImageOwnerAlias',ImageOwnerAlias)
-
-	def get_SchedulerType(self):
+	def set_ImageOwnerAlias(self, ImageOwnerAlias):  # String
+		self.add_query_param('ImageOwnerAlias', ImageOwnerAlias)
+	def get_SchedulerType(self): # String
 		return self.get_query_params().get('SchedulerType')
 
-	def set_SchedulerType(self,SchedulerType):
-		self.add_query_param('SchedulerType',SchedulerType)
\ No newline at end of file
+	def set_SchedulerType(self, SchedulerType):  # String
+		self.add_query_param('SchedulerType', SchedulerType)
