@@ -25,26 +25,24 @@ class SetGWSInstanceUserRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'EHPC', '2018-04-12', 'SetGWSInstanceUser')
 		self.set_method('GET')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_InstanceId(self):
+	def get_InstanceId(self): # String
 		return self.get_query_params().get('InstanceId')
 
-	def set_InstanceId(self,InstanceId):
-		self.add_query_param('InstanceId',InstanceId)
-
-	def get_UserUid(self):
+	def set_InstanceId(self, InstanceId):  # String
+		self.add_query_param('InstanceId', InstanceId)
+	def get_UserUid(self): # String
 		return self.get_query_params().get('UserUid')
 
-	def set_UserUid(self,UserUid):
-		self.add_query_param('UserUid',UserUid)
-
-	def get_UserName(self):
+	def set_UserUid(self, UserUid):  # String
+		self.add_query_param('UserUid', UserUid)
+	def get_UserName(self): # String
 		return self.get_query_params().get('UserName')
 
-	def set_UserName(self,UserName):
-		self.add_query_param('UserName',UserName)
\ No newline at end of file
+	def set_UserName(self, UserName):  # String
+		self.add_query_param('UserName', UserName)
