@@ -25,32 +25,29 @@ class UpdateQueueConfigRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'EHPC', '2018-04-12', 'UpdateQueueConfig')
 		self.set_method('GET')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_QueueName(self):
+	def get_QueueName(self): # String
 		return self.get_query_params().get('QueueName')
 
-	def set_QueueName(self,QueueName):
-		self.add_query_param('QueueName',QueueName)
-
-	def get_ClusterId(self):
+	def set_QueueName(self, QueueName):  # String
+		self.add_query_param('QueueName', QueueName)
+	def get_ClusterId(self): # String
 		return self.get_query_params().get('ClusterId')
 
-	def set_ClusterId(self,ClusterId):
-		self.add_query_param('ClusterId',ClusterId)
-
-	def get_ResourceGroupId(self):
+	def set_ClusterId(self, ClusterId):  # String
+		self.add_query_param('ClusterId', ClusterId)
+	def get_ResourceGroupId(self): # String
 		return self.get_query_params().get('ResourceGroupId')
 
-	def set_ResourceGroupId(self,ResourceGroupId):
-		self.add_query_param('ResourceGroupId',ResourceGroupId)
-
-	def get_ComputeInstanceType(self):
+	def set_ResourceGroupId(self, ResourceGroupId):  # String
+		self.add_query_param('ResourceGroupId', ResourceGroupId)
+	def get_ComputeInstanceType(self): # String
 		return self.get_query_params().get('ComputeInstanceType')
 
-	def set_ComputeInstanceType(self,ComputeInstanceType):
-		self.add_query_param('ComputeInstanceType',ComputeInstanceType)
\ No newline at end of file
+	def set_ComputeInstanceType(self, ComputeInstanceType):  # String
+		self.add_query_param('ComputeInstanceType', ComputeInstanceType)
